@@ -63,7 +63,7 @@ def nb_dist(x, y):
     1.4142135623730951
     """
     sum_ = 0
-    for x_i, y_i in zip(x, y):  # noqa B905
+    for x_i, y_i in zip(x, y):  # noqa: B905
         sum_ += (x_i - y_i) ** 2
     dist = np.sqrt(sum_)
     return dist
@@ -529,11 +529,9 @@ def alpha_shape_auto(
     if return_circles:
         return_radius = True
     if xys.shape[0] < 4:
-        from shapely import ops
-
         if xys.shape[0] == 3:
-            multipoint = ops.cascaded_union([geom.Point(xy) for xy in xys])
-            alpha_shape = multipoint.convex_hull.buffer(0)
+            multipoint = geom.MultiPoint(xys)
+            alpha_shape = multipoint.convex_hull
         else:
             alpha_shape = geom.Polygon([])
         if xys.shape[0] == 1:
@@ -651,7 +649,7 @@ def _construct_centers(a, b, radius):
         return down_x, down_y
 
 
-def _filter_holes(geoms, points):  # noqa ARG001
+def _filter_holes(geoms, points):  # noqa: ARG001
     """
     Filter hole polygons using a computational geometry solution
     """
